atomate.qchem.firetasks.tests package — atomate 0.9.2 documentation

# atomate.qchem.firetasks.tests package

## Submodules

## atomate.qchem.firetasks.tests.test_fragmenter module

class `atomate.qchem.firetasks.tests.test_fragmenter.` `TestFragmentMolecule`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `setUp`(lpad=False)

    Create scratch directory(removes the old one if there is one) and change to it. Also initialize launchpad.

  classmethod `setUpClass`()

    Hook method for setting up class fixture before running tests in the class.

  `tearDown`()

    Remove the scratch directory and teardown the test db.

  `test_EC_neg`()
  `test_babel_PC_depth_0_vs_depth_10`()
  `test_babel_PC_frag1`()
  `test_babel_PC_with_RO_depth_0_vs_depth_10`()
  `test_babel_TFSI`()
  `test_build_new_FWs`()
  `test_build_unique_relevant_molecules`()
  `test_build_unique_relevant_molecules_with_triplets`()
  `test_edges_given_PC`()
  `test_edges_given_PC_frag1`()
  `test_edges_given_TFSI`()
  `test_in_database_and_EC_neg_frag`()
  `test_in_database_through_build_new_FWs`()
  `test_in_database_with_actual_database`()
  `test_neg_TFSI`()
  `test_neg_TFSI_with_additional_charges`()

## atomate.qchem.firetasks.tests.test_geo_transformations module

class `atomate.qchem.firetasks.tests.test_geo_transformations.` `TestGeoTransformations`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `setUp`(lpad=False)

    Create scratch directory(removes the old one if there is one) and change to it. Also initialize launchpad.

  classmethod `setUpClass`()

    Hook method for setting up class fixture before running tests in the class.

  `tearDown`()

    Remove the scratch directory and teardown the test db.

  `test_rotate_torsion`()

## atomate.qchem.firetasks.tests.test_run_calc module

class `atomate.qchem.firetasks.tests.test_run_calc.` `TestFakeRunQChem`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `setUp`(lpad=False)

    Create scratch directory(removes the old one if there is one) and change to it. Also initialize launchpad.

  `tearDown`()

    Remove the scratch directory and teardown the test db.

  `test_RunQChemFake`()

class `atomate.qchem.firetasks.tests.test_run_calc.` `TestRunCalcQChem`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `setUp`(lpad=False)

    Create scratch directory(removes the old one if there is one) and change to it. Also initialize launchpad.

  `tearDown`()

    Remove the scratch directory and teardown the test db.

  `test_RunQChemCustodian_FF_basic_defaults`()
  `test_RunQChemCustodian_FF_basic_not_defaults`()
  `test_RunQChemCustodian_FF_using_fw_spec_defaults`()
  `test_RunQChemCustodian_FF_using_fw_spec_not_defaults`()
  `test_RunQChemCustodian_basic_defaults`()
  `test_RunQChemCustodian_basic_not_defaults`()
  `test_RunQChemCustodian_using_fw_spec_defaults`()
  `test_RunQChemCustodian_using_fw_spec_not_defaults`()
  `test_RunQChemDirect_basic`()
  `test_RunQChemDirect_with_fw_spec`()

## atomate.qchem.firetasks.tests.test_write_inputs module

class `atomate.qchem.firetasks.tests.test_write_inputs.` `TestWriteInputQChem`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `setUp`(lpad=False)

    Create scratch directory(removes the old one if there is one) and change to it. Also initialize launchpad.

  classmethod `setUpClass`()

    Hook method for setting up class fixture before running tests in the class.

  `tearDown`()

    Remove the scratch directory and teardown the test db.

  `test_write_custom_input`()
  `test_write_input`()
  `test_write_input_from_io_set`()
  `test_write_input_from_io_set_diff_mol`()
  `test_write_input_from_io_set_diff_mol_pcm`()
  `test_write_input_from_io_set_write_dir`()

## Module contents